Crate spl_memo

Crate spl_memo 

๐Ÿ‘ŽDeprecated since 6.1.0:

Please use spl-memo-interface for instruction types, and pinocchio-memo-program for the program implementation

A program that accepts a string of encoded characters and verifies that it parses, while verifying and logging signers. Currently handles UTF-8 characters.

โš ๏ธ DEPRECATED

This crate has been deprecated and is no longer actively maintained.

Please use spl-memo-interface for instruction types, and pinocchio-memo-program for the program implementation.

Re-exports

pub use solana_account_info;
pub use solana_instruction;
pub use solana_msg;
pub use solana_program_entrypoint;
pub use solana_program_error;
pub use solana_pubkey;

Modules

processorDeprecated
Program state processor
v1
Legacy symbols from Memo version 1

Constants

ID
The const program ID.

Functions

build_memoDeprecated
Build a memo instruction, possibly signed
check_id
Returns true if given address is the ID.
id
Returns the ID.